@@ -95,8 +95,7 @@ static mapper_setup_t* mapper_lookup_table[] = {
 	&mapper_shuffle_setup,
 	&mapper_skip_trivial_records_setup,
 	&mapper_sort_setup,
-	// xxx temp for 5.4.0 -- will continue work after
-	// &mapper_sort_within_records_setup,
+	&mapper_sort_within_records_setup,
 	&mapper_stats1_setup,
 	&mapper_stats2_setup,
 	&mapper_step_setup,
