@@ -1,6 +1,6 @@
 // ================================================================
-// Array-only (open addressing) string-to-string hash set with linear probing
-// for collisions.
+// Array-only (open addressing) string-valued hash set with linear probing for
+// collisions.
 //
 // John Kerl 2012-08-13
 //
@@ -102,9 +102,7 @@ static int hss_find_index_for_key(hss_t* pset, char* key, int* pideal_index) {
 		if (++index >= pset->array_length)
 			index = 0;
 	}
-	fprintf(stderr, "%s: internal coding error detected in file %s at line %d.\n",
-		MLR_GLOBALS.bargv0, __FILE__, __LINE__);
-	exit(1);
+	MLR_INTERNAL_CODING_ERROR();
 }
 
 // ----------------------------------------------------------------
@@ -147,6 +145,8 @@ static void hss_enlarge(hss_t* pset) {
 		if (e.state == OCCUPIED)
 			hss_add(pset, e.key);
 	}
+
+	free(old_array);
 }
 
 // ----------------------------------------------------------------
