@@ -77,11 +77,7 @@ slls_t* mlr_reference_selected_values_from_record(lrec_t* prec, slls_t* pselecte
 void mlr_reference_values_from_record_into_string_array(lrec_t* prec, string_array_t* pselected_field_names,
 	string_array_t* pvalues)
 {
-	if (pselected_field_names->length != pvalues->length) {
-		fprintf(stderr, "%s: internal coding error detected in file %s at line %d.\n",
-			MLR_GLOBALS.bargv0, __FILE__, __LINE__);
-		exit(1);
-	}
+	MLR_INTERNAL_CODING_ERROR_IF(pselected_field_names->length != pvalues->length);
 	pvalues->strings_need_freeing = FALSE;
 	for (int i = 0; i < pselected_field_names->length; i++) {
 		char* selected_field_name = pselected_field_names->strings[i];
@@ -104,6 +100,29 @@ int record_has_all_keys(lrec_t* prec, slls_t* pselected_field_names) {
 	return TRUE;
 }
 
+// ----------------------------------------------------------------
+lhmss_t* mlr_reference_key_value_pairs_from_regex_names(lrec_t* prec, regex_t* pregexes, int num_regexes,
+	int invert_matches)
+{
+	lhmss_t* pmap = lhmss_alloc();
+
+	for (lrece_t* pe = prec->phead; pe != NULL; pe = pe->pnext) {
+		int matches_any = FALSE;
+		for (int i = 0; i < num_regexes; i++) {
+			regex_t* pregex = &pregexes[i];
+			if (regmatch_or_die(pregex, pe->key, 0, NULL)) {
+				matches_any = TRUE;
+				break;
+			}
+		}
+		if (matches_any ^ invert_matches) {
+			lhmss_put(pmap, pe->key, pe->value, NO_FREE);
+		}
+	}
+
+	return pmap;
+}
+
 // ----------------------------------------------------------------
 hss_t* hss_from_slls(slls_t* plist) {
 	hss_t* pset = hss_alloc();
