@@ -28,7 +28,8 @@
 #define MLHMMV_INITIAL_ARRAY_LENGTH 16
 
 // ----------------------------------------------------------------
-void mlhmmv_print_terminal(mv_t* pmv, int quote_keys_always, int quote_values_always, FILE* ostream);
+void mlhmmv_print_terminal(mv_t* pmv, int quote_keys_always, int quote_values_always,
+	FILE* ostream);
 
 // ----------------------------------------------------------------
 struct _mlhmmv_level_t; // forward reference
@@ -300,10 +301,10 @@ void mlhmmv_root_partial_to_lrecs(mlhmmv_root_t* pmap, sllmv_t* pkeys, sllmv_t*
 
 // For 'dump' in the DSL; also used by the lrec-to-JSON writer.
 void mlhmmv_root_print_json_stacked(mlhmmv_root_t* pmap,
-	int quote_keys_always, int quote_values_always, char* line_indent, char* line_term,
-	FILE* ostream);
-void mlhmmv_root_print_json_single_lines(mlhmmv_root_t* pmap, int quote_keys_always, int quote_values_always,
-	char* line_term, FILE* ostream);
+	int quote_keys_always, int quote_values_always,
+	char* line_indent, char* line_term, FILE* ostream);
+void mlhmmv_root_print_json_single_lines(mlhmmv_root_t* pmap, int quote_keys_always,
+	int quote_values_always, char* line_term, FILE* ostream);
 
 // Used for emit of localvars. Puts the xvalue in a single-key-value-pair map
 // keyed by the specified name. The xvalue is referenced, not copied.
