@@ -122,6 +122,19 @@ mlr_dsl_ast_node_t* mlr_dsl_ast_node_append_arg(
 	return pa;
 }
 
+mlr_dsl_ast_node_t* mlr_dsl_ast_node_append_arg_to_second_child(
+	mlr_dsl_ast_node_t* pa, mlr_dsl_ast_node_t* pb)
+{
+	MLR_INTERNAL_CODING_ERROR_IF(pa->pchildren == NULL);
+	MLR_INTERNAL_CODING_ERROR_IF(pa->pchildren->phead == NULL);
+	MLR_INTERNAL_CODING_ERROR_IF(pa->pchildren->phead->pnext == NULL);
+	MLR_INTERNAL_CODING_ERROR_IF(pa->pchildren->phead->pnext->pvvalue == NULL);
+
+	mlr_dsl_ast_node_append_arg(pa->pchildren->phead->pnext->pvvalue, pb);
+
+	return pa;
+}
+
 mlr_dsl_ast_node_t* mlr_dsl_ast_node_set_function_name(
 	mlr_dsl_ast_node_t* pa, char* name)
 {
@@ -267,6 +280,8 @@ char* mlr_dsl_ast_node_describe_type(mlr_dsl_ast_node_type_t type) {
 	case MD_AST_NODE_TYPE_STATEMENT_LIST:                        return "STATEMENT_LIST";                        break;
 	case MD_AST_NODE_TYPE_FUNC_DEF:                              return "FUNC_DEF";                              break;
 	case MD_AST_NODE_TYPE_FUNCTION_CALLSITE:                     return "FUNCTION_CALLSITE";                     break;
+	case MD_AST_NODE_TYPE_INDEXED_FUNCTION_CALLSITE:             return "INDEXED_FUNCTION_CALLSITE";             break;
+	case MD_AST_NODE_TYPE_INDEXED_FUNCTION_INDEX_LIST:           return "MD_AST_NODE_TYPE_INDEXED_FUNCTION_INDEX_LIST"; break;
 	case MD_AST_NODE_TYPE_SUBR_DEF:                              return "SUBR_DEF";                              break;
 	case MD_AST_NODE_TYPE_SUBR_CALLSITE:                         return "SUBR_CALLSITE";                         break;
 	case MD_AST_NODE_TYPE_UNTYPED_LOCAL_DEFINITION:              return "UNTYPED_LOCAL_DEFINITION";              break;
