@@ -102,8 +102,8 @@ typedef struct _rval_evaluator_b_bb_state_t {
 	rval_evaluator_t* parg2;
 } rval_evaluator_b_bb_state_t;
 
-// This is different from most of the lrec-evaluator functions in that it does short-circuiting:
-// since is logical AND, the LHS is not evaluated if the RHS is false.
+// This is different from most of the lrec-evaluator functions in that it does short-circuiting: since is logical AND,
+// the second argument is not evaluated if the first argument is false.
 static mv_t rval_evaluator_b_bb_and_func(void* pvstate, variables_t* pvars) {
 	rval_evaluator_b_bb_state_t* pstate = pvstate;
 
@@ -127,8 +127,8 @@ static mv_t rval_evaluator_b_bb_and_func(void* pvstate, variables_t* pvars) {
 	}
 }
 
-// This is different from most of the lrec-evaluator functions in that it does short-circuiting:
-// since is logical OR, the LHS is not evaluated if the RHS is true.
+// This is different from most of the lrec-evaluator functions in that it does short-circuiting: since is logical OR,
+// the second argument is not evaluated if the first argument is true.
 static mv_t rval_evaluator_b_bb_or_func(void* pvstate, variables_t* pvars) {
 	rval_evaluator_b_bb_state_t* pstate = pvstate;
 
@@ -978,6 +978,52 @@ rval_evaluator_t* rval_evaluator_alloc_from_x_xi_func(mv_binary_func_t* pfunc,
 	return pevaluator;
 }
 
+// ----------------------------------------------------------------
+typedef struct _rval_evaluator_s_si_state_t {
+	mv_binary_func_t* pfunc;
+	rval_evaluator_t* parg1;
+	rval_evaluator_t* parg2;
+} rval_evaluator_s_si_state_t;
+
+static mv_t rval_evaluator_s_si_func(void* pvstate, variables_t* pvars) {
+	rval_evaluator_s_si_state_t* pstate = pvstate;
+	mv_t val1 = pstate->parg1->pprocess_func(pstate->parg1->pvstate, pvars);
+	mv_t val2 = pstate->parg2->pprocess_func(pstate->parg2->pvstate, pvars);
+
+	if (val1.type != MT_EMPTY && val1.type != MT_STRING) {
+		return mv_error();
+	}
+	if (val2.type != MT_INT) {
+		return mv_error();
+	}
+
+	// nullity of 1st argument handled by full disposition matrices
+	return pstate->pfunc(&val1, &val2);
+}
+static void rval_evaluator_s_si_free(rval_evaluator_t* pevaluator) {
+	rval_evaluator_s_si_state_t* pstate = pevaluator->pvstate;
+	pstate->parg1->pfree_func(pstate->parg1);
+	pstate->parg2->pfree_func(pstate->parg2);
+	free(pstate);
+	free(pevaluator);
+}
+
+rval_evaluator_t* rval_evaluator_alloc_from_s_si_func(mv_binary_func_t* pfunc,
+	rval_evaluator_t* parg1, rval_evaluator_t* parg2)
+{
+	rval_evaluator_s_si_state_t* pstate = mlr_malloc_or_die(sizeof(rval_evaluator_s_si_state_t));
+	pstate->pfunc = pfunc;
+	pstate->parg1 = parg1;
+	pstate->parg2 = parg2;
+
+	rval_evaluator_t* pevaluator = mlr_malloc_or_die(sizeof(rval_evaluator_t));
+	pevaluator->pvstate = pstate;
+	pevaluator->pprocess_func = rval_evaluator_s_si_func;
+	pevaluator->pfree_func = rval_evaluator_s_si_free;
+
+	return pevaluator;
+}
+
 // ----------------------------------------------------------------
 typedef struct _rval_evaluator_x_ns_state_t {
 	mv_binary_func_t* pfunc;
