@@ -4,8 +4,8 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include <sys/stat.h>
-#include <sys/mman.h>
 #include "lib/mlrutil.h"
+#include "lib/mlrescape.h"
 #include "lib/mlr_globals.h"
 #include "file_ingestor_stdio.h"
 
@@ -30,11 +30,12 @@ void* file_ingestor_stdio_vopen(void* pvstate, char* prepipe, char* filename) {
 		}
 
 	} else {
-		char* command = mlr_malloc_or_die(strlen(prepipe) + 3 + strlen(filename) + 1);
+		char* escaped_filename = alloc_file_name_escaped_for_popen(filename);
+		char* command = mlr_malloc_or_die(strlen(prepipe) + 3 + strlen(escaped_filename) + 1);
 		if (streq(filename, "-"))
 			sprintf(command, "%s", prepipe);
 		else
-			sprintf(command, "%s < %s", prepipe, filename);
+			sprintf(command, "%s < %s", prepipe, escaped_filename);
 		FILE* input_stream = popen(command, "r");
 		if (input_stream == NULL) {
 			fprintf(stderr, "%s: Couldn't popen \"%s\" for read.\n", MLR_GLOBALS.bargv0, command);
@@ -43,10 +44,11 @@ void* file_ingestor_stdio_vopen(void* pvstate, char* prepipe, char* filename) {
 		}
 		file_contents_buffer = read_fp_into_memory(input_stream, &file_size);
 		if (file_contents_buffer == NULL) {
-			fprintf(stderr, "%s: Couldn't open popen for read: \"%s\".\n", MLR_GLOBALS.bargv0, command);
+			fprintf(stderr, "%s: Couldn't open popen output for read: \"%s\".\n", MLR_GLOBALS.bargv0, command);
 			exit(1);
 		}
 		pclose(input_stream);
+		free(escaped_filename);
 		free(command);
 	}
 	file_ingestor_stdio_state_t* pstate = mlr_malloc_or_die(sizeof(file_ingestor_stdio_state_t));
