@@ -174,6 +174,8 @@ static lrec_t* lrec_reader_stdio_csvlite_process(void* pvstate, void* pvhandle,
 					? split_csvlite_header_line_single_ifs(hline, pstate->ifs[0], pstate->allow_repeat_ifs)
 					: split_csvlite_header_line_multi_ifs(hline, pstate->ifs, pstate->ifslen, pstate->allow_repeat_ifs);
 				if (pheader_fields->length == 0) {
+					slls_free(pheader_fields);
+					free(hline);
 					pstate->expect_header_line_next = TRUE;
 					if (pstate->pheader_keeper != NULL) {
 						pstate->pheader_keeper = NULL;
@@ -268,7 +270,7 @@ slls_t* split_csvlite_header_line_single_ifs(char* line, char ifs, int allow_rep
 			p++;
 	}
 	char* start = p;
-	for ( ; *p; p++) {
+	for ( ; *p; ) {
 		if (*p == ifs) {
 			*p = 0;
 			p++;
@@ -278,6 +280,8 @@ slls_t* split_csvlite_header_line_single_ifs(char* line, char ifs, int allow_rep
 			}
 			slls_append_no_free(plist, start);
 			start = p;
+		} else {
+			p++;
 		}
 	}
 	if (allow_repeat_ifs && *start == 0) {
@@ -300,7 +304,7 @@ slls_t* split_csvlite_header_line_multi_ifs(char* line, char* ifs, int ifslen, i
 			p += ifslen;
 	}
 	char* start = p;
-	for ( ; *p; p++) {
+	for ( ; *p; ) {
 		if (streqn(p, ifs, ifslen)) {
 			*p = 0;
 			p += ifslen;
@@ -310,6 +314,8 @@ slls_t* split_csvlite_header_line_multi_ifs(char* line, char* ifs, int ifslen, i
 			}
 			slls_append_no_free(plist, start);
 			start = p;
+		} else {
+			p++;
 		}
 	}
 	if (allow_repeat_ifs && *start == 0) {
