@@ -17,7 +17,7 @@ string_builder_t* sb_alloc(int alloc_length) {
 }
 
 // ----------------------------------------------------------------
-void  sb_free(string_builder_t* psb) {
+void sb_free(string_builder_t* psb) {
 	if (psb == NULL)
 		return;
 	free(psb->buffer);
@@ -59,11 +59,23 @@ char* sb_finish(string_builder_t* psb) {
 	return rv;
 }
 
+char* sb_finish_with_length(string_builder_t* psb, int* pline_length) {
+	sb_append_char(psb, '\0');
+	int alloc_length = (psb->used_length + BLOCK_LENGTH_MASK) & BLOCK_LENGTH_NMASK;
+	char* rv = mlr_malloc_or_die(alloc_length);
+	memcpy(rv, psb->buffer, psb->used_length);
+	// Line length doesn't include null terminator; used length does.
+	*pline_length = psb->used_length - 1;
+	psb->used_length  = 0;
+	return rv;
+}
+
 // ----------------------------------------------------------------
 void _sb_enlarge(string_builder_t* psb) {
 	int new_alloc_length = psb->alloc_length * 2;
 	char* new_buffer = mlr_malloc_or_die(new_alloc_length);
 	memcpy(new_buffer, psb->buffer, psb->used_length);
+	free(psb->buffer);
 	psb->alloc_length = new_alloc_length;
 	psb->buffer = new_buffer;
 }
