@@ -161,7 +161,7 @@ static void mapper_filter_usage(FILE* o, char* argv0, char* verb) {
 	fprintf(o, "\n");
 	fprintf(o, "Examples:\n");
 	fprintf(o, "  %s %s 'log10($count) > 4.0'\n", argv0, verb);
-	fprintf(o, "  %s %s 'FNR == 2          (second record in each file)'\n", argv0, verb);
+	fprintf(o, "  %s %s 'FNR == 2'         (second record in each file)\n", argv0, verb);
 	fprintf(o, "  %s %s 'urand() < 0.001'  (subsampling)\n", argv0, verb);
 	fprintf(o, "  %s %s '$color != \"blue\" && $value > 4.2'\n", argv0, verb);
 	fprintf(o, "  %s %s '($x<.5 && $y<.5) || ($x>.5 && $y>.5)'\n", argv0, verb);
@@ -454,8 +454,8 @@ static mapper_t* shared_parse_cli(int* pargi, int argc, char** argv,
 	*pargi = argi;
 	return mapper_put_or_filter_alloc(mlr_dsl_expression, ppredefines, print_ast,
 		trace_stack_allocation, trace_execution,
-		past, put_output_disabled, do_final_filter, negate_final_filter, type_inferencing, oosvar_flatten_separator,
-		flush_every_record, pwriter_opts, pmain_writer_opts);
+		past, put_output_disabled, do_final_filter, negate_final_filter, type_inferencing,
+		oosvar_flatten_separator, flush_every_record, pwriter_opts, pmain_writer_opts);
 }
 
 // ----------------------------------------------------------------
