@@ -10,6 +10,7 @@ extern mapper_setup_t mapper_bootstrap_setup;
 extern mapper_setup_t mapper_cat_setup;
 extern mapper_setup_t mapper_check_setup;
 extern mapper_setup_t mapper_clean_whitespace_setup;
+extern mapper_setup_t mapper_count_setup;
 extern mapper_setup_t mapper_count_distinct_setup;
 extern mapper_setup_t mapper_count_similar_setup;
 extern mapper_setup_t mapper_cut_setup;
@@ -45,6 +46,7 @@ extern mapper_setup_t mapper_seqgen_setup;
 extern mapper_setup_t mapper_shuffle_setup;
 extern mapper_setup_t mapper_skip_trivial_records_setup;
 extern mapper_setup_t mapper_sort_setup;
+extern mapper_setup_t mapper_sort_within_records_setup;
 // xxx temp for 5.4.0 -- will continue work after
 // extern mapper_setup_t mapper_sort_within_records_setup;
 extern mapper_setup_t mapper_stats1_setup;
