@@ -18,7 +18,7 @@ lrec_writer_t* lrec_writer_json_alloc(int stack_vertically, int wrap_json_output
 	int json_quote_int_keys, int json_quote_non_string_values,
 	char* output_json_flatten_separator, char* line_term);
 lrec_writer_t* lrec_writer_nidx_alloc(char* ors, char* ofs);
-lrec_writer_t* lrec_writer_pprint_alloc(char* ors, char ofs, int right_align, int barred);
+lrec_writer_t* lrec_writer_pprint_alloc(char* ors, char ofs, int right_align, int barred, int headerless_output);
 lrec_writer_t* lrec_writer_xtab_alloc(char* ofs, char* ops, int right_justify_value);
 
 // Pops and frees the lrecs in the argument list without sllv-freeing the list structure itself.
