@@ -6,15 +6,27 @@ import (
 	"os"
 
 	"miller/clitypes"
-	"miller/mapping"
+	"miller/dsl/cst"
+	"miller/lib"
+	"miller/transforming"
 	"miller/version"
 )
 
+const ASV_FS = "\x1f"
+const ASV_RS = "\x1e"
+const USV_FS = "\xe2\x90\x9f"
+const USV_RS = "\xe2\x90\x9e"
+
+// TODO: move somewhere else; maybe clitypes
+const ASV_FS_FOR_HELP = "0x1f"
+const ASV_RS_FOR_HELP = "0x1e"
+const USV_FS_FOR_HELP = "U+241F (UTF-8 0xe2909f)"
+const USV_RS_FOR_HELP = "U+241E (UTF-8 0xe2909e)"
+
 // ----------------------------------------------------------------
 func ParseCommandLine(args []string) (
 	options clitypes.TOptions,
-	recordMappers []mapping.IRecordMapper,
-	filenames []string,
+	recordTransformers []transforming.IRecordTransformer,
 	err error,
 ) {
 	options = clitypes.DefaultOptions()
@@ -88,52 +100,54 @@ func ParseCommandLine(args []string) (
 	//		return nil;
 	//	}
 
-	//	// Construct the mapper list for single use, e.g. the normal streaming case wherein the
-	//	// mappers operate on all input files. Also retain information needed to construct them
+	//	// Construct the transformer list for single use, e.g. the normal streaming case wherein the
+	//	// transformers operate on all input files. Also retain information needed to construct them
 	//	// for each input file, for in-place mode.
-	//	options.mapper_argb = argi;
+	//	options.transformer_argb = argi;
 	//	options.original_argv = args;
 	//	options.non_in_place_argv = copy_argv(args);
 	//	options.argc = argc;
-	//	*ppmapper_list = cli_parse_mappers(options.non_in_place_argv, &argi, argc, popts);
-	recordMappers, err = parseMappers(args, &argi, argc, &options)
+	//	*pptransformer_list = cli_parse_transformers(options.non_in_place_argv, &argi, argc, popts);
+	recordTransformers, err = parseTransformers(args, &argi, argc, &options)
 	if err != nil {
-		return options, recordMappers, filenames, err
+		return options, recordTransformers, err
 	}
 
-	filenames = args[argi:]
+	// There may already be one or more because of --from on the command line,
+	// so append.
+	for _, arg := range args[argi:] {
+		options.FileNames = append(options.FileNames, arg)
+	}
 
 	// E.g. mlr -n put -v '...'
 	if options.NoInput {
-		filenames = nil
+		options.FileNames = nil
 	}
 
-	//	if (options.do_in_place && (options.filenames == nil || options.filenames.length == 0)) {
+	//	if (options.do_in_place && (options.FileNames == nil || options.FileNames.length == 0)) {
 	//		fmt.Fprintf(os.Stderr, "%s: -I option (in-place operation) requires input files.\n", os.Args[0]);
 	//		os.Exit(1);
 	//	}
 
-	//	if (options.have_rand_seed) {
-	//		mtrand_init(options.rand_seed);
-	//	} else {
-	//		mtrand_init_default();
-	//	}
+	if options.HaveRandSeed {
+		lib.SeedRandom(options.RandSeed)
+	}
 
-	return options, recordMappers, filenames, nil
+	return options, recordTransformers, nil
 }
 
 // ----------------------------------------------------------------
-// Returns a list of mappers, from the starting point in args given by *pargi.
-// Bumps *pargi to point to remaining post-mapper-setup args, i.e. filenames.
+// Returns a list of transformers, from the starting point in args given by *pargi.
+// Bumps *pargi to point to remaining post-transformer-setup args, i.e. filenames.
 
-func parseMappers(
+func parseTransformers(
 	args []string,
 	pargi *int,
 	argc int,
 	options *clitypes.TOptions,
-) ([]mapping.IRecordMapper, error) {
+) ([]transforming.IRecordTransformer, error) {
 
-	mapperList := make([]mapping.IRecordMapper, 0)
+	transformerList := make([]transforming.IRecordTransformer, 0)
 	argi := *pargi
 
 	// Allow then-chains to start with an initial 'then': 'mlr verb1 then verb2 then verb3' or
@@ -152,8 +166,8 @@ func parseMappers(
 		checkArgCount(args, argi, argc, 1)
 		verb := args[argi]
 
-		mapperSetup := lookUpMapperSetup(verb)
-		if mapperSetup == nil {
+		transformerSetup := lookUpTransformerSetup(verb)
+		if transformerSetup == nil {
 			fmt.Fprintf(os.Stderr,
 				"%s: verb \"%s\" not found. Please use \"%s --help\" for a list.\n",
 				os.Args[0], verb, os.Args[0])
@@ -162,9 +176,9 @@ func parseMappers(
 
 		// It's up to the parse func to print its usage on CLI-parse failure.
 		// Also note: this assumes main reader/writer opts are all parsed
-		// *before* mapper parse-CLI methods are invoked.
+		// *before* transformer parse-CLI methods are invoked.
 
-		mapper := mapperSetup.ParseCLIFunc(
+		transformer := transformerSetup.ParseCLIFunc(
 			&argi,
 			argc,
 			args,
@@ -173,17 +187,17 @@ func parseMappers(
 			&options.WriterOptions,
 		)
 
-		if mapper == nil {
+		if transformer == nil {
 			// Error message already printed out
 			os.Exit(1)
 		}
 
-		//		if (mapperSetup.IgnoresInput && len(mapperList) == 0) {
+		//		if (transformerSetup.IgnoresInput && len(transformerList) == 0) {
 		//			// e.g. then-chain starts with seqgen
 		//			options.no_input = true;
 		//		}
 
-		mapperList = append(mapperList, mapper)
+		transformerList = append(transformerList, transformer)
 
 		if argi >= argc || args[argi] != "then" {
 			break
@@ -192,7 +206,7 @@ func parseMappers(
 	}
 
 	*pargi = argi
-	return mapperList, nil
+	return transformerList, nil
 }
 
 // ----------------------------------------------------------------
@@ -219,21 +233,17 @@ func parseTerminalUsage(args []string, argc int, argi int) bool {
 		listAllVerbsRaw(os.Stdout)
 		return true
 
-		//	} else if args[argi] == "--list-all-functions-raw" || args[argi] == "-F" {
-		//		fmgr_t* pfmgr = fmgr_alloc();
-		//		fmgr_list_all_functions_raw(pfmgr, os.Stdout);
-		//		fmgr_free(pfmgr, nil);
-		//		return true;
+	} else if args[argi] == "--list-all-functions-raw" || args[argi] == "-F" {
+		cst.BuiltinFunctionManagerInstance.ListBuiltinFunctionsRaw(os.Stdout)
+		return true
 		//	} else if args[argi] == "--list-all-functions-as-table" {
 		//		fmgr_t* pfmgr = fmgr_alloc();
 		//		fmgr_list_all_functions_as_table(pfmgr, os.Stdout);
 		//		fmgr_free(pfmgr, nil);
 		//		return true;
-		//	} else if args[argi] == "--help-all-functions" || args[argi] == "-f" {
-		//		fmgr_t* pfmgr = fmgr_alloc();
-		//		fmgr_function_usage(pfmgr, os.Stdout, nil);
-		//		fmgr_free(pfmgr, nil);
-		//		return true;
+	} else if args[argi] == "--help-all-functions" || args[argi] == "-f" {
+		cst.BuiltinFunctionManagerInstance.ListBuiltinFunctionUsages(os.Stdout)
+		return true
 		//	} else if args[argi] == "--help-function" || args[argi] == "--hf" {
 		//		checkArgCount(args, argi, argc, 2);
 		//		fmgr_t* pfmgr = fmgr_alloc();
@@ -349,17 +359,17 @@ func parseReaderOptions(args []string, argc int, pargi *int, readerOptions *clit
 		//		readerOptions.json_array_ingest = JSON_ARRAY_INGEST_AS_MAP;
 		//		argi += 1;
 		//
-		//	} else if args[argi] == "--implicit-csv-header" {
-		//		readerOptions.use_implicit_csv_header = true;
-		//		argi += 1;
-		//
-		//	} else if args[argi] == "--no-implicit-csv-header" {
-		//		readerOptions.use_implicit_csv_header = false;
-		//		argi += 1;
-		//
-		//	} else if args[argi] == "--allow-ragged-csv-input" || args[argi] == "--ragged" {
-		//		readerOptions.allow_ragged_csv_input = true;
-		//		argi += 1;
+	} else if args[argi] == "--implicit-csv-header" {
+		readerOptions.UseImplicitCSVHeader = true
+		argi += 1
+
+	} else if args[argi] == "--no-implicit-csv-header" {
+		readerOptions.UseImplicitCSVHeader = false
+		argi += 1
+
+	} else if args[argi] == "--allow-ragged-csv-input" || args[argi] == "--ragged" {
+		readerOptions.AllowRaggedCSVInput = true
+		argi += 1
 
 		//	} else if args[argi] == "-i" {
 		//		checkArgCount(args, argi, argc, 2);
@@ -403,44 +413,43 @@ func parseReaderOptions(args []string, argc int, pargi *int, readerOptions *clit
 		readerOptions.InputFileFormat = "csv"
 		argi += 1
 
-		//	} else if args[argi] == "--icsvlite" {
-		//		readerOptions.InputFileFormat = "csvlite";
-		//		argi += 1;
-		//
-		//	} else if args[argi] == "--itsv" {
-		//		readerOptions.InputFileFormat = "csv";
-		//		readerOptions.IFS = "\t";
-		//		argi += 1;
-		//
-		//	} else if args[argi] == "--itsvlite" {
-		//		readerOptions.InputFileFormat = "csvlite";
-		//		readerOptions.IFS = "\t";
-		//		argi += 1;
-		//
-		//	} else if args[argi] == "--iasv" {
-		//		readerOptions.InputFileFormat = "csv";
-		//		readerOptions.IFS = ASV_FS;
-		//		readerOptions.IRS = ASV_RS;
-		//		argi += 1;
-		//
-		//	} else if args[argi] == "--iasvlite" {
-		//		readerOptions.InputFileFormat = "csvlite";
-		//		readerOptions.IFS = ASV_FS;
-		//		readerOptions.IRS = ASV_RS;
-		//		argi += 1;
-		//
-		//	} else if args[argi] == "--iusv" {
-		//		readerOptions.InputFileFormat = "csv";
-		//		readerOptions.IFS = USV_FS;
-		//		readerOptions.IRS = USV_RS;
-		//		argi += 1;
-		//
-		//	} else if args[argi] == "--iusvlite" {
-		//		readerOptions.InputFileFormat = "csvlite";
-		//		readerOptions.IFS = USV_FS;
-		//		readerOptions.IRS = USV_RS;
-		//		argi += 1;
-		//
+	} else if args[argi] == "--icsvlite" {
+		readerOptions.InputFileFormat = "csvlite"
+		argi += 1
+
+	} else if args[argi] == "--itsv" {
+		readerOptions.InputFileFormat = "csv"
+		readerOptions.IFS = "\t"
+		argi += 1
+	} else if args[argi] == "--itsvlite" {
+		readerOptions.InputFileFormat = "csvlite"
+		readerOptions.IFS = "\t"
+		argi += 1
+
+	} else if args[argi] == "--iasv" {
+		readerOptions.InputFileFormat = "csvlite"
+		readerOptions.IFS = ASV_FS
+		readerOptions.IRS = ASV_RS
+		argi += 1
+
+	} else if args[argi] == "--iasvlite" {
+		readerOptions.InputFileFormat = "csvlite"
+		readerOptions.IFS = ASV_FS
+		readerOptions.IRS = ASV_RS
+		argi += 1
+
+	} else if args[argi] == "--iusv" {
+		readerOptions.InputFileFormat = "csvlite"
+		readerOptions.IFS = USV_FS
+		readerOptions.IRS = USV_RS
+		argi += 1
+
+	} else if args[argi] == "--iusvlite" {
+		readerOptions.InputFileFormat = "csvlite"
+		readerOptions.IFS = USV_FS
+		readerOptions.IRS = USV_RS
+		argi += 1
+
 	} else if args[argi] == "--idkvp" {
 		readerOptions.InputFileFormat = "dkvp"
 		argi += 1
@@ -453,26 +462,26 @@ func parseReaderOptions(args []string, argc int, pargi *int, readerOptions *clit
 		readerOptions.InputFileFormat = "nidx"
 		argi += 1
 
-		//	} else if args[argi] == "--ixtab" {
-		//		readerOptions.InputFileFormat = "xtab";
-		//		argi += 1;
-		//
+	} else if args[argi] == "--ixtab" {
+		readerOptions.InputFileFormat = "xtab"
+		argi += 1
+
 		//	} else if args[argi] == "--ipprint" {
 		//		readerOptions.InputFileFormat        = "csvlite";
 		//		readerOptions.IFS              = " ";
 		//		readerOptions.allow_repeat_ifs = true;
 		//		argi += 1;
 		//
-		//	} else if args[argi] == "--mmap" {
-		//		// No-op as of 5.6.3 (mmap is being abandoned) but don't break
-		//		// the command-line user experience.
-		//		argi += 1;
-		//
-		//	} else if args[argi] == "--no-mmap" {
-		//		// No-op as of 5.6.3 (mmap is being abandoned) but don't break
-		//		// the command-line user experience.
-		//		argi += 1;
-		//
+	} else if args[argi] == "--mmap" {
+		// No-op as of 5.6.3 (mmap is being abandoned) but don't break
+		// the command-line user experience.
+		argi += 1
+
+	} else if args[argi] == "--no-mmap" {
+		// No-op as of 5.6.3 (mmap is being abandoned) but don't break
+		// the command-line user experience.
+		argi += 1
+
 		//	} else if args[argi] == "--prepipe" {
 		//		checkArgCount(args, argi, argc, 2);
 		//		readerOptions.prepipe = args[argi+1];
@@ -520,10 +529,9 @@ func parseWriterOptions(args []string, argc int, pargi *int, writerOptions *clit
 		writerOptions.OFS = SeparatorFromArg(args[argi+1])
 		argi += 2
 
-		//	} else if args[argi] == "--headerless-csv-output" {
-		//		writerOptions.headerless_csv_output = true;
-		//		argi += 1;
-		//
+	} else if args[argi] == "--headerless-csv-output" {
+		writerOptions.HeaderlessCSVOutput = true
+		argi += 1
 	} else if args[argi] == "--ops" {
 		checkArgCount(args, argi, argc, 2)
 		writerOptions.OPS = SeparatorFromArg(args[argi+1])
@@ -533,14 +541,17 @@ func parseWriterOptions(args []string, argc int, pargi *int, writerOptions *clit
 		//		writerOptions.right_justify_xtab_value = true;
 		//		argi += 1;
 		//
-		//	} else if args[argi] == "--jvstack" {
-		//		writerOptions.stack_json_output_vertically = true;
-		//		argi += 1;
-		//
-		//	} else if args[argi] == "--jlistwrap" {
-		//		writerOptions.wrap_json_output_in_outer_list = true;
-		//		argi += 1;
-		//
+
+		// TODO: comment in detail this is accepted as a no-op for backward
+		// compatibility in Miller 6 and above.
+	} else if args[argi] == "--jvstack" {
+		//writerOptions.stack_json_output_vertically = true;
+		argi += 1
+
+	} else if args[argi] == "--jlistwrap" {
+		writerOptions.WrapJSONOutputInOuterList = true
+		argi += 1
+
 		//	} else if args[argi] == "--jknquoteint" {
 		//		writerOptions.json_quote_int_keys = false;
 		//		argi += 1;
@@ -570,44 +581,44 @@ func parseWriterOptions(args []string, argc int, pargi *int, writerOptions *clit
 		writerOptions.OutputFileFormat = "csv"
 		argi += 1
 
-		//	} else if args[argi] == "--ocsvlite" {
-		//		writerOptions.OutputFileFormat = "csvlite";
-		//		argi += 1;
-		//
-		//	} else if args[argi] == "--otsv" {
-		//		writerOptions.OutputFileFormat = "csv";
-		//		writerOptions.OFS = "\t";
-		//		argi += 1;
-		//
-		//	} else if args[argi] == "--otsvlite" {
-		//		writerOptions.OutputFileFormat = "csvlite";
-		//		writerOptions.OFS = "\t";
-		//		argi += 1;
-		//
-		//	} else if args[argi] == "--oasv" {
-		//		writerOptions.OutputFileFormat = "csv";
-		//		writerOptions.OFS = ASV_FS;
-		//		writerOptions.ORS = ASV_RS;
-		//		argi += 1;
-		//
-		//	} else if args[argi] == "--oasvlite" {
-		//		writerOptions.OutputFileFormat = "csvlite";
-		//		writerOptions.OFS = ASV_FS;
-		//		writerOptions.ORS = ASV_RS;
-		//		argi += 1;
-		//
-		//	} else if args[argi] == "--ousv" {
-		//		writerOptions.OutputFileFormat = "csv";
-		//		writerOptions.OFS = USV_FS;
-		//		writerOptions.ORS = USV_RS;
-		//		argi += 1;
-		//
-		//	} else if args[argi] == "--ousvlite" {
-		//		writerOptions.OutputFileFormat = "csvlite";
-		//		writerOptions.OFS = USV_FS;
-		//		writerOptions.ORS = USV_RS;
-		//		argi += 1;
-		//
+	} else if args[argi] == "--ocsvlite" {
+		writerOptions.OutputFileFormat = "csvlite"
+		argi += 1
+
+	} else if args[argi] == "--otsv" {
+		writerOptions.OutputFileFormat = "csv"
+		writerOptions.OFS = "\t"
+		argi += 1
+
+	} else if args[argi] == "--otsvlite" {
+		writerOptions.OutputFileFormat = "csvlite"
+		writerOptions.OFS = "\t"
+		argi += 1
+
+	} else if args[argi] == "--oasv" {
+		writerOptions.OutputFileFormat = "csvlite"
+		writerOptions.OFS = ASV_FS
+		writerOptions.ORS = ASV_RS
+		argi += 1
+
+	} else if args[argi] == "--oasvlite" {
+		writerOptions.OutputFileFormat = "csvlite"
+		writerOptions.OFS = ASV_FS
+		writerOptions.ORS = ASV_RS
+		argi += 1
+
+	} else if args[argi] == "--ousv" {
+		writerOptions.OutputFileFormat = "csvlite"
+		writerOptions.OFS = USV_FS
+		writerOptions.ORS = USV_RS
+		argi += 1
+
+	} else if args[argi] == "--ousvlite" {
+		writerOptions.OutputFileFormat = "csvlite"
+		writerOptions.OFS = USV_FS
+		writerOptions.ORS = USV_RS
+		argi += 1
+
 		//	} else if args[argi] == "--omd" {
 		//		writerOptions.OutputFileFormat = "markdown";
 		//		argi += 1;
@@ -640,9 +651,9 @@ func parseWriterOptions(args []string, argc int, pargi *int, writerOptions *clit
 		//		writerOptions.right_align_pprint = true;
 		//		argi += 1;
 		//
-		//	} else if args[argi] == "--barred" {
-		//		writerOptions.pprint_barred = true;
-		//		argi += 1;
+	} else if args[argi] == "--barred" {
+		writerOptions.BarredPprintOutput = true
+		argi += 1
 		//
 		//	} else if args[argi] == "--quote-all" {
 		//		writerOptions.oquoting = QUOTE_ALL;
@@ -729,25 +740,27 @@ func parseReaderWriterOptions(
 		writerOptions.OutputFileFormat = "csv"
 		argi += 1
 
-		//	} else if args[argi] == "--csvlite" {
-		//		readerOptions.InputFileFormat = "csvlite";
-		//		writerOptions.OutputFileFormat = "csvlite";
-		//		argi += 1;
-		//
-		//	} else if args[argi] == "--tsv" {
-		//		readerOptions.InputFileFormat = writerOptions.OutputFileFormat = "csv";
-		//		readerOptions.IFS = "\t";
-		//		writerOptions.OFS = "\t";
-		//		argi += 1;
-		//
-		//	} else if args[argi] == "--tsvlite" || args[argi] == "-t" {
-		//		readerOptions.InputFileFormat = writerOptions.OutputFileFormat = "csvlite";
-		//		readerOptions.IFS = "\t";
-		//		writerOptions.OFS = "\t";
-		//		argi += 1;
-		//
+	} else if args[argi] == "--csvlite" {
+		readerOptions.InputFileFormat = "csvlite"
+		writerOptions.OutputFileFormat = "csv"
+		argi += 1
+
+	} else if args[argi] == "--tsv" {
+		readerOptions.InputFileFormat = "csv"
+		writerOptions.OutputFileFormat = "csv"
+		readerOptions.IFS = "\t"
+		writerOptions.OFS = "\t"
+		argi += 1
+
+	} else if args[argi] == "--tsvlite" || args[argi] == "-t" {
+		readerOptions.InputFileFormat = "csvlite"
+		writerOptions.OutputFileFormat = "csvlite"
+		readerOptions.IFS = "\t"
+		writerOptions.OFS = "\t"
+		argi += 1
+
 		//	} else if args[argi] == "--asv" {
-		//		readerOptions.InputFileFormat = writerOptions.OutputFileFormat = "csv";
+		//		readerOptions.InputFileFormat = writerOptions.OutputFileFormat = "csvlite";
 		//		readerOptions.IFS = ASV_FS;
 		//		writerOptions.OFS = ASV_FS;
 		//		readerOptions.IRS = ASV_RS;
@@ -763,7 +776,7 @@ func parseReaderWriterOptions(
 		//		argi += 1;
 		//
 		//	} else if args[argi] == "--usv" {
-		//		readerOptions.InputFileFormat = writerOptions.OutputFileFormat = "csv";
+		//		readerOptions.InputFileFormat = writerOptions.OutputFileFormat = "csvlite";
 		//		readerOptions.IFS = USV_FS;
 		//		writerOptions.OFS = USV_FS;
 		//		readerOptions.IRS = USV_RS;
@@ -805,11 +818,12 @@ func parseReaderWriterOptions(
 		//		writerOptions.OFS = "\t";
 		//		argi += 1;
 		//
-		//	} else if args[argi] == "--xtab" {
-		//		readerOptions.InputFileFormat = "xtab";
-		//		writerOptions.OutputFileFormat = "xtab";
-		//		argi += 1;
-		//
+	} else if args[argi] == "--xtab" {
+		readerOptions.InputFileFormat = "xtab"
+		writerOptions.OutputFileFormat = "xtab"
+		argi += 1
+
+		// TODO: make a fixed-width scanner
 		//	} else if args[argi] == "--pprint" {
 		//		readerOptions.InputFileFormat        = "csvlite";
 		//		readerOptions.IFS              = " ";
@@ -817,81 +831,81 @@ func parseReaderWriterOptions(
 		//		writerOptions.OutputFileFormat        = "pprint";
 		//		argi += 1;
 		//
-		//	} else if args[argi] == "--c2t" {
-		//		readerOptions.InputFileFormat = "csv";
-		//		readerOptions.IRS       = "auto";
-		//		writerOptions.OutputFileFormat = "csv";
-		//		writerOptions.ORS       = "auto";
-		//		writerOptions.OFS       = "\t";
-		//		argi += 1;
-		//	} else if args[argi] == "--c2d" {
-		//		readerOptions.InputFileFormat = "csv";
-		//		readerOptions.IRS       = "auto";
-		//		writerOptions.OutputFileFormat = "dkvp";
-		//		argi += 1;
-		//	} else if args[argi] == "--c2n" {
-		//		readerOptions.InputFileFormat = "csv";
-		//		readerOptions.IRS       = "auto";
-		//		writerOptions.OutputFileFormat = "nidx";
-		//		argi += 1;
-		//	} else if args[argi] == "--c2j" {
-		//		readerOptions.InputFileFormat = "csv";
-		//		readerOptions.IRS       = "auto";
-		//		writerOptions.OutputFileFormat = "json";
-		//		argi += 1;
-		//	} else if args[argi] == "--c2p" {
-		//		readerOptions.InputFileFormat = "csv";
-		//		readerOptions.IRS       = "auto";
-		//		writerOptions.OutputFileFormat = "pprint";
-		//		argi += 1;
-		//	} else if args[argi] == "--c2x" {
-		//		readerOptions.InputFileFormat = "csv";
-		//		readerOptions.IRS       = "auto";
-		//		writerOptions.OutputFileFormat = "xtab";
-		//		argi += 1;
+	} else if args[argi] == "--c2t" {
+		readerOptions.InputFileFormat = "csv"
+		readerOptions.IRS = "auto"
+		writerOptions.OutputFileFormat = "csv"
+		writerOptions.ORS = "auto"
+		writerOptions.OFS = "\t"
+		argi += 1
+	} else if args[argi] == "--c2d" {
+		readerOptions.InputFileFormat = "csv"
+		readerOptions.IRS = "auto"
+		writerOptions.OutputFileFormat = "dkvp"
+		argi += 1
+	} else if args[argi] == "--c2n" {
+		readerOptions.InputFileFormat = "csv"
+		readerOptions.IRS = "auto"
+		writerOptions.OutputFileFormat = "nidx"
+		argi += 1
+	} else if args[argi] == "--c2j" {
+		readerOptions.InputFileFormat = "csv"
+		readerOptions.IRS = "auto"
+		writerOptions.OutputFileFormat = "json"
+		argi += 1
+	} else if args[argi] == "--c2p" {
+		readerOptions.InputFileFormat = "csv"
+		readerOptions.IRS = "auto"
+		writerOptions.OutputFileFormat = "pprint"
+		argi += 1
+	} else if args[argi] == "--c2x" {
+		readerOptions.InputFileFormat = "csv"
+		readerOptions.IRS = "auto"
+		writerOptions.OutputFileFormat = "xtab"
+		argi += 1
 		//	} else if args[argi] == "--c2m" {
 		//		readerOptions.InputFileFormat = "csv";
 		//		readerOptions.IRS       = "auto";
 		//		writerOptions.OutputFileFormat = "markdown";
 		//		argi += 1;
 		//
-		//	} else if args[argi] == "--t2c" {
-		//		readerOptions.InputFileFormat = "csv";
-		//		readerOptions.IFS       = "\t";
-		//		readerOptions.IRS       = "auto";
-		//		writerOptions.OutputFileFormat = "csv";
-		//		writerOptions.ORS       = "auto";
-		//		argi += 1;
-		//	} else if args[argi] == "--t2d" {
-		//		readerOptions.InputFileFormat = "csv";
-		//		readerOptions.IFS       = "\t";
-		//		readerOptions.IRS       = "auto";
-		//		writerOptions.OutputFileFormat = "dkvp";
-		//		argi += 1;
-		//	} else if args[argi] == "--t2n" {
-		//		readerOptions.InputFileFormat = "csv";
-		//		readerOptions.IFS       = "\t";
-		//		readerOptions.IRS       = "auto";
-		//		writerOptions.OutputFileFormat = "nidx";
-		//		argi += 1;
-		//	} else if args[argi] == "--t2j" {
-		//		readerOptions.InputFileFormat = "csv";
-		//		readerOptions.IFS       = "\t";
-		//		readerOptions.IRS       = "auto";
-		//		writerOptions.OutputFileFormat = "json";
-		//		argi += 1;
-		//	} else if args[argi] == "--t2p" {
-		//		readerOptions.InputFileFormat = "csv";
-		//		readerOptions.IFS       = "\t";
-		//		readerOptions.IRS       = "auto";
-		//		writerOptions.OutputFileFormat = "pprint";
-		//		argi += 1;
-		//	} else if args[argi] == "--t2x" {
-		//		readerOptions.InputFileFormat = "csv";
-		//		readerOptions.IFS       = "\t";
-		//		readerOptions.IRS       = "auto";
-		//		writerOptions.OutputFileFormat = "xtab";
-		//		argi += 1;
+	} else if args[argi] == "--t2c" {
+		readerOptions.InputFileFormat = "csv"
+		readerOptions.IFS = "\t"
+		readerOptions.IRS = "auto"
+		writerOptions.OutputFileFormat = "csv"
+		writerOptions.ORS = "auto"
+		argi += 1
+	} else if args[argi] == "--t2d" {
+		readerOptions.InputFileFormat = "csv"
+		readerOptions.IFS = "\t"
+		readerOptions.IRS = "auto"
+		writerOptions.OutputFileFormat = "dkvp"
+		argi += 1
+	} else if args[argi] == "--t2n" {
+		readerOptions.InputFileFormat = "csv"
+		readerOptions.IFS = "\t"
+		readerOptions.IRS = "auto"
+		writerOptions.OutputFileFormat = "nidx"
+		argi += 1
+	} else if args[argi] == "--t2j" {
+		readerOptions.InputFileFormat = "csv"
+		readerOptions.IFS = "\t"
+		readerOptions.IRS = "auto"
+		writerOptions.OutputFileFormat = "json"
+		argi += 1
+	} else if args[argi] == "--t2p" {
+		readerOptions.InputFileFormat = "csv"
+		readerOptions.IFS = "\t"
+		readerOptions.IRS = "auto"
+		writerOptions.OutputFileFormat = "pprint"
+		argi += 1
+	} else if args[argi] == "--t2x" {
+		readerOptions.InputFileFormat = "csv"
+		readerOptions.IFS = "\t"
+		readerOptions.IRS = "auto"
+		writerOptions.OutputFileFormat = "xtab"
+		argi += 1
 		//	} else if args[argi] == "--t2m" {
 		//		readerOptions.InputFileFormat = "csv";
 		//		readerOptions.IFS       = "\t";
@@ -899,97 +913,97 @@ func parseReaderWriterOptions(
 		//		writerOptions.OutputFileFormat = "markdown";
 		//		argi += 1;
 		//
-		//	} else if args[argi] == "--d2c" {
-		//		readerOptions.InputFileFormat = "dkvp";
-		//		writerOptions.OutputFileFormat = "csv";
-		//		writerOptions.ORS       = "auto";
-		//		argi += 1;
-		//	} else if args[argi] == "--d2t" {
-		//		readerOptions.InputFileFormat = "dkvp";
-		//		writerOptions.OutputFileFormat = "csv";
-		//		writerOptions.ORS       = "auto";
-		//		writerOptions.OFS       = "\t";
-		//		argi += 1;
-		//	} else if args[argi] == "--d2n" {
-		//		readerOptions.InputFileFormat = "dkvp";
-		//		writerOptions.OutputFileFormat = "nidx";
-		//		argi += 1;
-		//	} else if args[argi] == "--d2j" {
-		//		readerOptions.InputFileFormat = "dkvp";
-		//		writerOptions.OutputFileFormat = "json";
-		//		argi += 1;
-		//	} else if args[argi] == "--d2p" {
-		//		readerOptions.InputFileFormat = "dkvp";
-		//		writerOptions.OutputFileFormat = "pprint";
-		//		argi += 1;
-		//	} else if args[argi] == "--d2x" {
-		//		readerOptions.InputFileFormat = "dkvp";
-		//		writerOptions.OutputFileFormat = "xtab";
-		//		argi += 1;
+	} else if args[argi] == "--d2c" {
+		readerOptions.InputFileFormat = "dkvp"
+		writerOptions.OutputFileFormat = "csv"
+		writerOptions.ORS = "auto"
+		argi += 1
+	} else if args[argi] == "--d2t" {
+		readerOptions.InputFileFormat = "dkvp"
+		writerOptions.OutputFileFormat = "csv"
+		writerOptions.ORS = "auto"
+		writerOptions.OFS = "\t"
+		argi += 1
+	} else if args[argi] == "--d2n" {
+		readerOptions.InputFileFormat = "dkvp"
+		writerOptions.OutputFileFormat = "nidx"
+		argi += 1
+	} else if args[argi] == "--d2j" {
+		readerOptions.InputFileFormat = "dkvp"
+		writerOptions.OutputFileFormat = "json"
+		argi += 1
+	} else if args[argi] == "--d2p" {
+		readerOptions.InputFileFormat = "dkvp"
+		writerOptions.OutputFileFormat = "pprint"
+		argi += 1
+	} else if args[argi] == "--d2x" {
+		readerOptions.InputFileFormat = "dkvp"
+		writerOptions.OutputFileFormat = "xtab"
+		argi += 1
 		//	} else if args[argi] == "--d2m" {
 		//		readerOptions.InputFileFormat = "dkvp";
 		//		writerOptions.OutputFileFormat = "markdown";
 		//		argi += 1;
 		//
-		//	} else if args[argi] == "--n2c" {
-		//		readerOptions.InputFileFormat = "nidx";
-		//		writerOptions.OutputFileFormat = "csv";
-		//		writerOptions.ORS       = "auto";
-		//		argi += 1;
-		//	} else if args[argi] == "--n2t" {
-		//		readerOptions.InputFileFormat = "nidx";
-		//		writerOptions.OutputFileFormat = "csv";
-		//		writerOptions.ORS       = "auto";
-		//		writerOptions.OFS       = "\t";
-		//		argi += 1;
-		//	} else if args[argi] == "--n2d" {
-		//		readerOptions.InputFileFormat = "nidx";
-		//		writerOptions.OutputFileFormat = "dkvp";
-		//		argi += 1;
-		//	} else if args[argi] == "--n2j" {
-		//		readerOptions.InputFileFormat = "nidx";
-		//		writerOptions.OutputFileFormat = "json";
-		//		argi += 1;
-		//	} else if args[argi] == "--n2p" {
-		//		readerOptions.InputFileFormat = "nidx";
-		//		writerOptions.OutputFileFormat = "pprint";
-		//		argi += 1;
-		//	} else if args[argi] == "--n2x" {
-		//		readerOptions.InputFileFormat = "nidx";
-		//		writerOptions.OutputFileFormat = "xtab";
-		//		argi += 1;
+	} else if args[argi] == "--n2c" {
+		readerOptions.InputFileFormat = "nidx"
+		writerOptions.OutputFileFormat = "csv"
+		writerOptions.ORS = "auto"
+		argi += 1
+	} else if args[argi] == "--n2t" {
+		readerOptions.InputFileFormat = "nidx"
+		writerOptions.OutputFileFormat = "csv"
+		writerOptions.ORS = "auto"
+		writerOptions.OFS = "\t"
+		argi += 1
+	} else if args[argi] == "--n2d" {
+		readerOptions.InputFileFormat = "nidx"
+		writerOptions.OutputFileFormat = "dkvp"
+		argi += 1
+	} else if args[argi] == "--n2j" {
+		readerOptions.InputFileFormat = "nidx"
+		writerOptions.OutputFileFormat = "json"
+		argi += 1
+	} else if args[argi] == "--n2p" {
+		readerOptions.InputFileFormat = "nidx"
+		writerOptions.OutputFileFormat = "pprint"
+		argi += 1
+	} else if args[argi] == "--n2x" {
+		readerOptions.InputFileFormat = "nidx"
+		writerOptions.OutputFileFormat = "xtab"
+		argi += 1
 		//	} else if args[argi] == "--n2m" {
 		//		readerOptions.InputFileFormat = "nidx";
 		//		writerOptions.OutputFileFormat = "markdown";
 		//		argi += 1;
 		//
-		//	} else if args[argi] == "--j2c" {
-		//		readerOptions.InputFileFormat = "json";
-		//		writerOptions.OutputFileFormat = "csv";
-		//		writerOptions.ORS       = "auto";
-		//		argi += 1;
-		//	} else if args[argi] == "--j2t" {
-		//		readerOptions.InputFileFormat = "json";
-		//		writerOptions.OutputFileFormat = "csv";
-		//		writerOptions.ORS       = "auto";
-		//		writerOptions.OFS       = "\t";
-		//		argi += 1;
-		//	} else if args[argi] == "--j2d" {
-		//		readerOptions.InputFileFormat = "json";
-		//		writerOptions.OutputFileFormat = "dkvp";
-		//		argi += 1;
-		//	} else if args[argi] == "--j2n" {
-		//		readerOptions.InputFileFormat = "json";
-		//		writerOptions.OutputFileFormat = "nidx";
-		//		argi += 1;
-		//	} else if args[argi] == "--j2p" {
-		//		readerOptions.InputFileFormat = "json";
-		//		writerOptions.OutputFileFormat = "pprint";
-		//		argi += 1;
-		//	} else if args[argi] == "--j2x" {
-		//		readerOptions.InputFileFormat = "json";
-		//		writerOptions.OutputFileFormat = "xtab";
-		//		argi += 1;
+	} else if args[argi] == "--j2c" {
+		readerOptions.InputFileFormat = "json"
+		writerOptions.OutputFileFormat = "csv"
+		writerOptions.ORS = "auto"
+		argi += 1
+	} else if args[argi] == "--j2t" {
+		readerOptions.InputFileFormat = "json"
+		writerOptions.OutputFileFormat = "csv"
+		writerOptions.ORS = "auto"
+		writerOptions.OFS = "\t"
+		argi += 1
+	} else if args[argi] == "--j2d" {
+		readerOptions.InputFileFormat = "json"
+		writerOptions.OutputFileFormat = "dkvp"
+		argi += 1
+	} else if args[argi] == "--j2n" {
+		readerOptions.InputFileFormat = "json"
+		writerOptions.OutputFileFormat = "nidx"
+		argi += 1
+	} else if args[argi] == "--j2p" {
+		readerOptions.InputFileFormat = "json"
+		writerOptions.OutputFileFormat = "pprint"
+		argi += 1
+	} else if args[argi] == "--j2x" {
+		readerOptions.InputFileFormat = "json"
+		writerOptions.OutputFileFormat = "xtab"
+		argi += 1
 		//	} else if args[argi] == "--j2m" {
 		//		readerOptions.InputFileFormat = "json";
 		//		writerOptions.OutputFileFormat = "markdown";
@@ -1041,42 +1055,42 @@ func parseReaderWriterOptions(
 		//		writerOptions.OutputFileFormat        = "markdown";
 		//		argi += 1;
 		//
-		//	} else if args[argi] == "--x2c" {
-		//		readerOptions.InputFileFormat = "xtab";
-		//		writerOptions.OutputFileFormat = "csv";
-		//		writerOptions.ORS       = "auto";
-		//		argi += 1;
-		//	} else if args[argi] == "--x2t" {
-		//		readerOptions.InputFileFormat = "xtab";
-		//		writerOptions.OutputFileFormat = "csv";
-		//		writerOptions.ORS       = "auto";
-		//		writerOptions.OFS       = "\t";
-		//		argi += 1;
-		//	} else if args[argi] == "--x2d" {
-		//		readerOptions.InputFileFormat = "xtab";
-		//		writerOptions.OutputFileFormat = "dkvp";
-		//		argi += 1;
-		//	} else if args[argi] == "--x2n" {
-		//		readerOptions.InputFileFormat = "xtab";
-		//		writerOptions.OutputFileFormat = "nidx";
-		//		argi += 1;
-		//	} else if args[argi] == "--x2j" {
-		//		readerOptions.InputFileFormat = "xtab";
-		//		writerOptions.OutputFileFormat = "json";
-		//		argi += 1;
-		//	} else if args[argi] == "--x2p" {
-		//		readerOptions.InputFileFormat = "xtab";
-		//		writerOptions.OutputFileFormat = "pprint";
-		//		argi += 1;
+	} else if args[argi] == "--x2c" {
+		readerOptions.InputFileFormat = "xtab"
+		writerOptions.OutputFileFormat = "csv"
+		writerOptions.ORS = "auto"
+		argi += 1
+	} else if args[argi] == "--x2t" {
+		readerOptions.InputFileFormat = "xtab"
+		writerOptions.OutputFileFormat = "csv"
+		writerOptions.ORS = "auto"
+		writerOptions.OFS = "\t"
+		argi += 1
+	} else if args[argi] == "--x2d" {
+		readerOptions.InputFileFormat = "xtab"
+		writerOptions.OutputFileFormat = "dkvp"
+		argi += 1
+	} else if args[argi] == "--x2n" {
+		readerOptions.InputFileFormat = "xtab"
+		writerOptions.OutputFileFormat = "nidx"
+		argi += 1
+	} else if args[argi] == "--x2j" {
+		readerOptions.InputFileFormat = "xtab"
+		writerOptions.OutputFileFormat = "json"
+		argi += 1
+	} else if args[argi] == "--x2p" {
+		readerOptions.InputFileFormat = "xtab"
+		writerOptions.OutputFileFormat = "pprint"
+		argi += 1
 		//	} else if args[argi] == "--x2m" {
 		//		readerOptions.InputFileFormat = "xtab";
 		//		writerOptions.OutputFileFormat = "markdown";
 		//		argi += 1;
 		//
-		//	} else if args[argi] == "-N" {
-		//		readerOptions.use_implicit_csv_header = true;
-		//		writerOptions.headerless_csv_output = true;
-		//		argi += 1;
+	} else if args[argi] == "-N" {
+		readerOptions.UseImplicitCSVHeader = true
+		writerOptions.HeaderlessCSVOutput = true
+		argi += 1
 	}
 	*pargi = argi
 	return argi != oargi
@@ -1101,11 +1115,11 @@ func parseMiscOptions(
 		//		options.do_in_place = true;
 		//		argi += 1;
 		//
-		//	} else if args[argi] == "--from" {
-		//		checkArgCount(args, argi, argc, 2);
-		//		slls_append(options.filenames, args[argi+1], NO_FREE);
-		//		argi += 2;
-		//
+	} else if args[argi] == "--from" {
+		checkArgCount(args, argi, argc, 2)
+		options.FileNames = append(options.FileNames, args[argi+1])
+		argi += 2
+
 		//	} else if args[argi] == "--ofmt" {
 		//		checkArgCount(args, argi, argc, 2);
 		//		options.ofmt = args[argi+1];
@@ -1129,20 +1143,20 @@ func parseMiscOptions(
 		//		}
 		//		argi += 2;
 		//
-		//	} else if args[argi] == "--seed" {
-		//		checkArgCount(args, argi, argc, 2);
-		//		if (sscanf(args[argi+1], "0x%x", &options.rand_seed) == 1) {
-		//			options.have_rand_seed = true;
-		//		} else if (sscanf(args[argi+1], "%u", &options.rand_seed) == 1) {
-		//			options.have_rand_seed = true;
-		//		} else {
-		//			fmt.Fprintf(os.Stderr,
-		//				"%s: --seed argument must be a decimal or hexadecimal integer; got \"%s\".\n",
-		//				os.Args[0], args[argi+1]);
-		//			mainUsageShort()
-		//			os.Exit(1);
-		//		}
-		//		argi += 2;
+	} else if args[argi] == "--seed" {
+		checkArgCount(args, argi, argc, 2)
+		randSeed, ok := lib.TryInt64FromString(args[argi+1])
+		if ok {
+			options.RandSeed = randSeed
+			options.HaveRandSeed = true
+		} else {
+			fmt.Fprintf(os.Stderr,
+				"%s: --seed argument must be a decimal or hexadecimal integer; got \"%s\".\n",
+				os.Args[0], args[argi+1])
+			mainUsageShort()
+			os.Exit(1)
+		}
+		argi += 2
 
 	}
 	*pargi = argi
