@@ -1,10 +1,10 @@
 package output
 
 import (
-	"miller/containers"
+	"miller/types"
 )
 
 // Convention: nil outrec signifies end of record stream
 type IRecordWriter interface {
-	Write(outrec *containers.Lrec)
+	Write(outrec *types.Mlrmap)
 }
