@@ -5,7 +5,7 @@ import (
 	"os"
 
 	"miller/clitypes"
-	"miller/containers"
+	"miller/types"
 )
 
 type RecordWriterDKVP struct {
@@ -23,13 +23,18 @@ func NewRecordWriterDKVP(writerOptions *clitypes.TWriterOptions) *RecordWriterDK
 }
 
 func (this *RecordWriterDKVP) Write(
-	outrec *containers.Lrec,
+	outrec *types.Mlrmap,
 ) {
 	// End of record stream: nothing special for this output format
 	if outrec == nil {
 		return
 	}
 
+	if outrec.FieldCount == 0 {
+		os.Stdout.WriteString(this.ors)
+		return
+	}
+
 	var buffer bytes.Buffer // 5x faster than fmt.Print() separately
 	for pe := outrec.Head; pe != nil; pe = pe.Next {
 		buffer.WriteString(*pe.Key)
