@@ -3,9 +3,10 @@ package output
 import (
 	"bytes"
 	"os"
+	"unicode/utf8"
 
 	"miller/clitypes"
-	"miller/containers"
+	"miller/types"
 )
 
 // ostream *os.File in constructors/factory
@@ -20,7 +21,7 @@ func NewRecordWriterXTAB(writerOptions *clitypes.TWriterOptions) *RecordWriterXT
 }
 
 func (this *RecordWriterXTAB) Write(
-	outrec *containers.Lrec,
+	outrec *types.Mlrmap,
 ) {
 	// End of record stream: nothing special for this output format
 	if outrec == nil {
@@ -29,7 +30,7 @@ func (this *RecordWriterXTAB) Write(
 
 	maxKeyLength := 1
 	for pe := outrec.Head; pe != nil; pe = pe.Next {
-		keyLength := len(*pe.Key)
+		keyLength := utf8.RuneCountInString(*pe.Key)
 		if keyLength > maxKeyLength {
 			maxKeyLength = keyLength
 		}
@@ -45,7 +46,7 @@ func (this *RecordWriterXTAB) Write(
 	}
 
 	for pe := outrec.Head; pe != nil; pe = pe.Next {
-		keyLength := len(*pe.Key)
+		keyLength := utf8.RuneCountInString(*pe.Key)
 		padLength := maxKeyLength - keyLength
 
 		buffer.WriteString(*pe.Key)
